@@ -4,13 +4,14 @@ import os
 from fabric.api import *
 from fabric.utils import _AttributeDict
 
+import time
+
 
 ez_env = _AttributeDict({
     'group': None,
-})
-
-ez_cloud = _AttributeDict({
-    'qingcloud': None,
+    'roles': None,
+    'cloud': None,
+    'cloud_processor': None,
 })
 
 
@@ -34,16 +35,7 @@ def _pssh(file):
     return machines
 
 
-def _bind_pssh(file):
-    """
-    Bind env from pssh-like file
-    :param file:
-    """
-    env.hosts = _pssh(file)
-    env.use_ssh_config = True
-
-
-def bind_hosts(curr, routes):
+def bind_hosts(curr, routes=None):
     """
     bind hosts from file
     :param curr:
@@ -51,27 +43,54 @@ def bind_hosts(curr, routes):
     :return:
     """
 
+    if not routes:
+        current_path = './config/fabez'
+
+        files = os.listdir(current_path)
+
+        routes = {}
+
+        for f in files:
+
+            if f.endswith('conf'):
+                k = f.rsplit('.')[0]
+                v = os.path.join(current_path, f)
+
+                if k == 'online':
+                    k = 'ol'
+                    pass
+
+                routes[k] = v
+
+                pass
+
+            pass
+
+        pass
+
     ez_env.group = curr
+    ez_env.roles = {}
+
 
     for k, v in routes.items():
         if k == curr:
-            _bind_pssh(v)
-            break
+            env.hosts = _pssh(v)
+            env.use_ssh_config = True
+            pass
+        if k == 'online':
+            k = 'ol'
+            pass
+        ez_env.roles[k] = _pssh(v)
         pass
     pass
 
 
-
-
-def bind_cloud(qingcloud=None,**kwargs):
-
-    if qingcloud:
-        ez_cloud.qingcloud = qingcloud
-
-
+def bind_cloud(cloud_options):
+    ez_env.cloud = cloud_options
     pass
 
 
 
 
 
+
