@@ -12,7 +12,7 @@ except:
     pass
 
 
-def init_fabric(hosts, dir, fabfile_name):
+def init_fabric(hosts, root, fabfile_name):
     """
     init fabfile system
     :param hosts:
@@ -20,24 +20,30 @@ def init_fabric(hosts, dir, fabfile_name):
     :return:
     """
 
-    if os.path.exists(dir) is False:
-        os.makedirs(dir, 0755)  # can cause OSError.
-    else:
-        print "Directory `%s' existed.skip init." % dir.replace(os.getcwd(), '.')
+    dir =  os.path.join(root,'fabez')
+    cabric_dir = os.path.join(root,'cabric')
 
+    dirs = [dir,cabric_dir]
+
+    for v in dirs:
+        if os.path.exists(v) is False:
+            os.makedirs(v, 0755)  # can cause OSError.
+        else:
+            print("Directory `%s' existed.skip init." % dir.replace(os.getcwd(), '.'))
 
     # create config files
 
     files = {
-        'dev': os.path.join(dir, 'dev.conf'),
-        'test': os.path.join(dir, 'test.conf'),
+        # 'dev': os.path.join(dir, 'dev.conf'),
+        'beta': os.path.join(dir, 'beta.conf'),
         'online': os.path.join(dir, 'online.conf'),
-        'fabfile': fabfile_name + '.py'
+        'fabfile': fabfile_name + '.py',
+        'cloud_file': os.path.join(cabric_dir, 'cloud.yaml'),
     }
 
     for k, f in files.items():
         if os.path.exists(f) is False:
-            if k == 'dev':
+            if k == 'beta':
                 with open(f, 'w') as fh:
                     for item in hosts:
                         print>> fh, item
@@ -53,6 +59,17 @@ def init_fabric(hosts, dir, fabfile_name):
                 with open(f, 'w') as fh:
                     print>> fh, template.replace('{0}', dir.replace(os.getcwd(), ''))
 
+                pass
+            elif k == 'cloud_file':
+                try:
+                    template = pkg_resources.resource_string('fabez', 'tpl/cloud.yaml')
+                except:
+                    template = open(os.path.join(os.path.dirname(__file__), 'tpl', 'cloud.yaml')).read()
+                    pass
+
+                with open(f, 'w') as fh:
+                    print>> fh, template.replace('{0}', dir.replace(os.getcwd(), ''))
+
                 pass
             else:
                 with open(f, 'w') as fh:
@@ -65,42 +82,44 @@ def main():
     importer = __import__
 
     a = ArgLoader((
-        ('Useage: fabez init [options] host'),
+        ('Useage: fabez init [host]'),
         '',
         'Arguments',
-        '    host         develop environment host group.',
+        '    host         pre-release environment host group.',
         '                     e.g:root@example.com,root1@example.com',
 
         'Actions',
         ('@init', 'init fabric file'),
-        ('@web', 'start fabez web-server'),
         '',
         'Options:',
-        ('--dir-name:', 'set config directory name,default is `./config/fabez`'),
-        ('--fabfile:', 'set fabfile name,default is `fabfile`'),
+        # ('--dir-name:', 'set config directory name,default is `./config/fabez`'),
+        # ('--fabfile:', 'set fabfile name,default is `fabfile`'),
         ('--debug', 'debug flag'),
         ('--help', 'print help document', '-h'),
     ))
 
     if a.options.get('--help'):
-        print a
+        print(a)
         return
 
     try:
         hosts = a.argv[1].split(',')
     except:
-        print "Please set your host group or use `--help` to see help manual."
-        sys.exit(-1)
-        pass
+        hosts = ''
 
-    config_name = a.options.get('--dir-name') or 'config'
-    fabfile_name = a.options.get('--fabfile') or 'fabfile'
+    # config_name = a.options.get('--dir-name') or 'config'
+    config_name = 'config'
+    # fabfile_name = a.options.get('--fabfile') or 'fabfile'
+    fabfile_name = 'fabfile'
 
-    config_path = os.path.join(os.getcwd(), config_name, 'fabez')
+
+    root = os.path.join(os.getcwd(), config_name)
 
     if a.actions.get('init'):
-        init_fabric(hosts, config_path, fabfile_name)
+        init_fabric(hosts, root, fabfile_name)
         return
+    else:
+        print(a)
 
     pass
 
