@@ -739,7 +739,7 @@ def server_smtp(host, domain, networks):
 
 
 # restart feature
-def restart_web(config=None):
+def restart_tengine(config=None):
     # supervisor_restart()
     if config:
         config_nginx(config)
@@ -748,6 +748,43 @@ def restart_web(config=None):
     run('service tengine restart')
 
 
+
+
+def restart_web(name,config=None,strict=False):
+    """
+    limit:
+    supervisor and nginx config name must be same
+    :param config:
+    :return:
+    """
+
+    if config:
+        config_nginx(config)
+        if strict:
+            run('service tengine reload')
+        else:
+            with settings(warn_only=True):
+                run('service tengine reload')
+                pass
+
+        config_supervisor(config)
+
+        run('service tengine stop')
+        run('service supervisord stop')
+        run('service supervisord start')
+        run('service tengine start')
+        return
+    else:
+        run('service tengine stop')
+        run('supervisorctl restart {}'.format(name))
+        run('service tengine start')
+
+    pass
+
+
+
+
+
 def restart_monit(config=None):
 
     if config:
@@ -770,10 +807,11 @@ def reboot_monit(name=None, config=None):
 
 def reboot_supervisor(name=None, config=None):
     if config:
+        run('service supervisord stop')
         config_supervisor(config)
-        run('service supervisord restart')
+        run('service supervisord start')
 
-    if name:
+    if name and not config:
         run('supervisorctl restart {}'.format(name))
 
 
